
# kia_hyundai
Connect to your Kia or Hyundai car.

# Usage
```
define my_car fhempy kia_hyundai USERNAME PASSWORD PIN CAR_TYPE REGION
```

USERNAME: E-Mail address of your Kia/Hyundai account
PASSWORD: Password of your Kia/Hyundai account
PIN: Car PIN
CAR_TYPE: Kia or Hyundai
REGION: Europe, USA or Canada
